@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: stage.py 1136 2007-02-23 05:25:10Z pronovic $
+# Revision : $Id: stage.py 1145 2007-02-24 17:30:34Z pronovic $
 # Purpose  : Implements the standard 'stage' action.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -124,7 +124,7 @@ def executeStage(configPath, options, config):
          peer.writeStageIndicator()
       except (ValueError, IOError, OSError), e:
          logger.error("Error staging [%s]: %s" % (peer.name, e))
-   writeIndicatorFile(config, dailyDir, config.options.backupUser, config.options.backupGroup)
+   writeIndicatorFile(dailyDir, STAGE_INDICATOR, config.options.backupUser, config.options.backupGroup)
    logger.info("Executed the 'stage' action successfully.")
 
 
