@@ -27,7 +27,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: store.py 1051 2007-01-07 01:01:46Z pronovic $
+# Revision : $Id: store.py 1136 2007-02-23 05:25:10Z pronovic $
 # Purpose  : Implements the standard 'store' action.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -64,6 +64,7 @@ from CedarBackup2.writers.dvdwriter import DvdWriter
 from CedarBackup2.writers.dvdwriter import MEDIA_DVDPLUSR, MEDIA_DVDPLUSRW
 from CedarBackup2.actions.constants import DIR_TIME_FORMAT, STAGE_INDICATOR, STORE_INDICATOR
 from CedarBackup2.config import DEFAULT_MEDIA_TYPE, DEFAULT_DEVICE_TYPE
+from CedarBackup2.actions.util import writeIndicatorFile
 
 
 ########################################################################
@@ -157,16 +158,20 @@ def createWriter(config):
    @raise ValueError: If there is a problem getting the writer.
    @raise IOError: If there is a problem creating the writer object.
    """
+   devicePath = config.store.devicePath
+   deviceScsiId = config.store.deviceScsiId
+   driveSpeed = config.store.driveSpeed
+   noEject = config.store.noEject
    deviceType = _getDeviceType(config)
    mediaType = _getMediaType(config)
-   if deviceMounted(config.store.devicePath):
-      raise IOError("Device [%s] is currently mounted." % (config.store.devicePath))
+   if deviceMounted(devicePath):
+      raise IOError("Device [%s] is currently mounted." % (devicePath))
    if deviceType == "cdwriter":
-      return CdWriter(config.store.devicePath, config.store.deviceScsiId, config.store.driveSpeed, mediaType)
+      return CdWriter(devicePath, deviceScsiId, driveSpeed, mediaType, noEject)
    elif deviceType == "dvdwriter":
-      return DvdWriter(config.store.devicePath, config.store.deviceScsiId, config.store.driveSpeed, mediaType)
+      return DvdWriter(devicePath, deviceScsiId, driveSpeed, mediaType, noEject)
    else:
-      raise ValueError("Device type [%s] is invalid." % config.store.deviceType)
+      raise ValueError("Device type [%s] is invalid." % deviceType)
 
 
 ########################
@@ -213,13 +218,9 @@ def writeStoreIndicator(config, stagingDirs):
    @param stagingDirs: Dictionary mapping directory path to date suffix.
    """
    for stagingDir in stagingDirs.keys():
-      filename = os.path.join(stagingDir, STORE_INDICATOR)
-      logger.debug("Writing store indicator [%s]." % filename)
-      try:
-         open(filename, "w").write("")
-         changeOwnership(filename, config.options.backupUser, config.options.backupGroup)
-      except Exception, e:
-         logger.error("Error writing store indicator: %s" % e)
+      writeIndicatorFile(stagingDir, STORE_INDICATOR, 
+                         config.options.backupUser, 
+                         config.options.backupGroup)
 
 
 ##############################
