@@ -30,7 +30,7 @@
 # Author   : Kenneth J. Pronovici <pronovic@ieee.org>
 # Language : Python (>= 2.3)
 # Project  : Cedar Backup, release 2
-# Revision : $Id: util.py 1083 2007-01-30 01:58:25Z pronovic $
+# Revision : $Id: util.py 1138 2007-02-24 04:15:50Z pronovic $
 # Purpose  : Provides general-purpose utilities.
 #
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
@@ -685,7 +685,7 @@ class DirectedGraph(object):
 # PathResolverSingleton class defkinition
 ########################################################################
 
-class PathResolverSingleton:
+class PathResolverSingleton(object):
 
    """
    Singleton used for resolving executable paths.
@@ -896,6 +896,23 @@ def sortDict(d):
    return [key for key, value in items]
 
 
+########################
+# removeKeys() function
+########################
+
+def removeKeys(d, keys):
+   """
+   Removes all of the keys from the dictionary.
+   The dictionary is altered in-place. 
+   Each key must exist in the dictionary.
+   @param d: Dictionary to operate on
+   @param keys: List of keys to remove
+   @raise KeyError: If one of the keys does not exist
+   """
+   for key in keys:
+      del d[key]
+
+
 #########################
 # convertSize() function
 #########################
@@ -1100,13 +1117,18 @@ def getUidGid(user, group):
 def changeOwnership(path, user, group):
    """
    Changes ownership of path to match the user and group.
-   This is a no-op if user/group functionality is not available on the platform.
+
+   This is a no-op if user/group functionality is not available on the
+   platform, or if the either passed-in user or group is C{None}.
+
    @param path: Path whose ownership to change.
    @param user: User which owns file.
    @param group: Group which owns file.
    """
    if _UID_GID_AVAILABLE:
-      if os.getuid() != 0:
+      if user is None or group is None:
+         logger.debug("User or group is None, so not attempting to change owner on [%s]." % path)
+      elif os.getuid() != 0:
          logger.debug("Not root, so not attempting to change owner on [%s]." % path)
       else:
          try:
@@ -1643,23 +1665,23 @@ def isStartOfWeek(startingDay):
 # buildNormalizedPath() function
 #################################
 
-def buildNormalizedPath(absPath):
+def buildNormalizedPath(path):
    """
-   Returns a "normalized" path based on an absolute path.
+   Returns a "normalized" path based on a path name.
 
    A "normalized" path has its leading C{'/'} or C{'.'} characters removed, and
    then converts all remaining whitespace and C{'/'} characters to the C{'_'}
    character.   As a special case, the absolute path C{/} will be normalized to
    just C{'-'}.
 
-   @param absPath: Absolute path
+   @param path: Path to normalize
 
    @return: Normalized path.
    """
-   if absPath == os.sep:
+   if path == os.sep:
       return "-"
    else:
-      normalized = absPath
+      normalized = path
       normalized = re.sub("^\.", "", normalized)
       normalized = re.sub("^\/", "", normalized)
       normalized = re.sub("\/", "-", normalized)
